@@ -1,7 +1,7 @@
 import asyncio
 import traceback
 import numpy as np
-import httpx
+import wget
 from aiohttp_retry import ExponentialRetry, RetryClient
 
 from nos import Client
@@ -70,14 +70,8 @@ class WYSF(BackendBase):
                 return False, '下载出错'
             else:
                 url = 'http://{}/{}'.format(self.domain, '{}_{}'.format(bucket, bucket_name))
-                print(url)
-                with httpx.stream('GET', url) as response:
-                    if response.status_code == 200:
-                        with open(download_path, mode='wb') as f:
-                            for chunk in response.iter_bytes():
-                                f.write(chunk)
-                    else:
-                        raise ValueError()
+                print('downloading {} -> {}'.format(url, download_path))
+                download_path = wget.download(url, download_path)
                 return True, download_path
         except Exception as e:
             if tries >= 3:
@@ -86,24 +80,7 @@ class WYSF(BackendBase):
                 return self.get(download_path, bucket, bucket_name, tries+1)
 
     async def get_async(self, download_path, bucket, bucket_name):
-        try:
-            url = 'http://{}/{}'.format(self.domain, '{}_{}'.format(bucket, bucket_name))
-            print(url)
-            retry_opts = ExponentialRetry(attempts=3)
-            async with RetryClient(retry_options=retry_opts) as session:
-                async with session.get(url) as response:
-                    if response.status == 200:
-                        with open(download_path, mode='wb') as f:
-                            while True:
-                                chunk = await response.content.read(4096)
-                                if not chunk:
-                                    break
-                                f.write(chunk)
-                    else:
-                        raise ValueError()
-            return True, download_path
-        except Exception as e:
-            return False, str(e)
+        return self.get(download_path, bucket, bucket_name)
 
     async def cleanup_old_files(self):
         objects = self.client.list_objects(self.default_bucket, prefix='tmp_file', limit=1000)
