@@ -49,6 +49,8 @@ class XRedis(Singleton):
             print('释放连接')
             self.conn.close()
             self.connection_lost = True
+            if self.heartbeat_thread.isAlive:
+                self.heartbeat_thread.join()
             del self.conn
     
     def _make_conn(self):
